@@ -1,7 +1,11 @@
-`linearRegression` <-
+linearRegression <-
 function (phen, gen = NULL, genZ = NULL, reference = "noia", 
     max.level = NULL, max.dom = NULL, fast = FALSE) 
 {
+    "is.diag" <- function(mat, threshold = 1e-06) {
+        return(all(mat[lower.tri(mat, diag = FALSE)] < threshold) && 
+            all(mat[upper.tri(mat, diag = FALSE)] < threshold))
+    }
     prep <- prepareRegression(phen = phen, gen = gen, genZ = genZ, 
         reference = reference, max.level = max.level, max.dom = max.dom, 
         fast = fast)
@@ -13,6 +17,9 @@ function (phen, gen = NULL, genZ = NULL, reference = "noia",
         nn <- colnames(prep$smat)
     }
     regression <- lm(prep$phen ~ prep$x + 0)
+    if (!is.diag(t(prep$x) %*% prep$x)) {
+        warning("The decomposition of genetic effects is not orthogonal.\n")
+    }
     ans <- prep
     class(ans) <- "noia.linear"
     ans$E <- coef(regression)
@@ -20,7 +27,8 @@ function (phen, gen = NULL, genZ = NULL, reference = "noia",
     ans$variances <- effectsVariances(ans)
     ans$std.dev <- summary(regression)$coef[, 2]
     ans$pvalues <- effectsPvalues(regression)
-    ans$resvar <- var(residuals(regression))
+    ans$resvar <- var(residuals(regression)) * (length(residuals(regression)) - 
+        1)/length(residuals(regression))
     ans$regression <- regression
     return(ans)
 }
